Installation — MSUMastro toolbox 0.1 documentation

# Installation

## This software

### Users

This software requires a python distribution that includes numpy and other packages that support scientific work with python. The easiest way to get these is to download and install the Anaconda python distribution. Note that the Anaconda distribution includes `astropy`.

Install the way you install most python software:

    pip install msumastro

### Developers

Install this software by downloading a copy from the github page for the code. On Mac/Linux do this by typing, in a terminal in the directory in which you want to run the code:

    git clone https://github.com/mwcraig/msumastro.git

Navigate to the directory in which you downloaded it and run:

    python setup.py develop

With this setup any changes you make to the source code will be immediately available to you without additional steps.

## Dependencies

### Python

This software has only been tested in python 2.7.x. It does not work in 3.x.

Note

Most of the requirements below will be taken care of automatically if you install msumastro with `pip` or `setup.py` as described above. The exceptions are numpy and scipy

### Python packages

#### Required

Nothing will work without these:

- numpy (included with anaconda): If you need to install it, please see the instructions at the SciPy download site. Some functionality may require SciPy.

- astropy (included with anaconda): If you need to install it, do so with:

      pip install astropy

- astropysics: Install with:

      pip install --pre astropysics

#### Very strongly recommended if you want to test your install

- pytest_capturelog: Install with:

      pip install pytest-capturelog

#### Required to build documentation

You only need to install the packages below if you want to build the documentation yourself:

- numpydoc: Install using either `pip`, or, if you have the Anaconda python distribution, like this:

      conda install numpydoc

- sphinx_argparse: Install it this way:

      pip install sphinx-argparse

### (mostly) Non-python software: astrometry.net

Note

There is one piece of python software you need for astrometry.net and for now you need to install it manually:

    pip install pyfits

If you want to be able to use the script Adding astrometry: run_astromtery.py you need a local installation of astrometry.net and sextractor (the latter works better than the source detection built into astrometry.net) The easiest way to do that (on a Mac) is with homebrew. Once you have installed homebrew the rest is easy (unless it fails, of course...):

- `brew tap camphogg/science` (only needs to be done once; connects the set of homebrew science formulae maintained by the maintainers of astrometry.net)
- `brew install sextractor` (note this can take a very long time to compile the linear algebra libraries)
- `brew install --env=std astrometry.net` [Note the option `--env=std`. It is necessary to ensure homebrew sees your python installation.]